@@ -105,10 +105,13 @@ def start():
 
     sysd_file['Unit'] = {
         'Description': PROJECT_NAME,
+        'After': 'network-online.target',
+        'Wants': 'network-online.target systemd-networkd-wait-online.service',
     }
     sysd_file['Service'] = {
         'ExecStart': f'{PY_EXEC_PATH} {daemon_path}',
         'Restart': 'on-failure',
+        'RestartSec': '60',
         'Environment': 'PYTHONUNBUFFERED=1',
     }
     sysd_file['Install'] = {
